# Sources / Attribution

-   `key_3.wav`: [@jim-ph (freesound.org)](https://freesound.org/people/jim-ph/sounds/194799/)
-   `key_4.wav`: [@s+e+m (freesound.org)](https://freesound.org/people/s+e+m/sounds/516261/)

Unfortunately I can't remember where I found the first 2 key sound files but if you know where they are from please let me know and I can give them proper credit
